==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/lxqt-panel/plugin-sensors/sensors_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>LXQtSensorsConfiguration</name>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="14"/>
        <source>Sensors Settings</source>
        <translation>センサーウィジェットの設定</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="30"/>
        <source>Common</source>
        <translation>共通</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="42"/>
        <source>Update interval (seconds)</source>
        <translation>更新頻度(秒)</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="49"/>
        <source>Temperature bar width</source>
        <translation>温度バーの幅</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="104"/>
        <source>Temperature scale</source>
        <translation>温度の単位</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="110"/>
        <source>Celsius</source>
        <translation>摂氏</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="120"/>
        <source>Fahrenheit</source>
        <translation>華氏</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="132"/>
        <source>Blink progress bars when the temperature is too high</source>
        <translation>高温時にバーを点滅</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="138"/>
        <source>Warning about high temperature</source>
        <translation>高温時に警告</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="152"/>
        <source>Sensors</source>
        <translation>センサー</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="168"/>
        <source>Detected chips:</source>
        <translation>検出されたチップ</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="175"/>
        <source>Chip features:</source>
        <translation>チップの機能:</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.cpp" line="195"/>
        <source>Enabled</source>
        <translation>有効</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.cpp" line="195"/>
        <source>Label</source>
        <translation>ラベル</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.cpp" line="195"/>
        <source>Color</source>
        <translation>色</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.13.0.orig.tar.xz: lxqt-l10n-0.13.0/lxqt-panel/plugin-sensors/sensors_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>LXQtSensorsConfiguration</name>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="14"/>
        <source>Sensors Settings</source>
        <translation>センサーウィジェットの設定</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="30"/>
        <source>Common</source>
        <translation>共通</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="42"/>
        <source>Update interval (seconds)</source>
        <translation>更新頻度(秒)</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="49"/>
        <source>Temperature bar width</source>
        <translation>温度バーの幅</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="104"/>
        <source>Temperature scale</source>
        <translation>温度の単位</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="110"/>
        <source>Celsius</source>
        <translation>摂氏</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="120"/>
        <source>Fahrenheit</source>
        <translation>華氏</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="132"/>
        <source>Blink progress bars when the temperature is too high</source>
        <translation>高温時にバーを点滅</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="138"/>
        <source>Warning about high temperature</source>
        <translation>高温時に警告</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="152"/>
        <source>Sensors</source>
        <translation>センサー</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="168"/>
        <source>Detected chips:</source>
        <translation>検出されたチップ:</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="175"/>
        <source>Chip features:</source>
        <translation>チップの機能:</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.cpp" line="195"/>
        <source>Enabled</source>
        <translation>有効</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.cpp" line="195"/>
        <source>Label</source>
        <translation>ラベル</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.cpp" line="195"/>
        <source>Color</source>
        <translation>色</translation>
    </message>
</context>
</TS>
